@@ -116,8 +116,8 @@ const char *musics_filenames[NB_CHIPTUNES + PADDING_FALCON] = {
 };
 
 #ifdef __LIBSDL2__
-#include <SDL.h>
-#include <SDL_mixer.h>
+#include <SDL2/SDL.h>
+#include <SDL2/SDL_mixer.h>
 #endif
 
 #ifdef __LIBSDL__
@@ -725,9 +725,9 @@ static void mrboom_api()
       char body[1024];
 #ifdef __LIBRETRO__
       sprintf(body, "{\n\"platform\":\"");
-#else 
+#else
       snprintf(body, sizeof(body), "{\n\"platform\":\"");
-#endif      
+#endif
       strcat(body,  PLATFORM);
 #ifdef __LIBSDL2__
       strcat(body, "\",\n\"version\":\"SDL2 ");
@@ -743,7 +743,7 @@ static void mrboom_api()
       say_hello = 0;
 #ifdef DEBUG
       conn = net_http_connection_new("http://localhost:4004/hello", "POST", body);
-#else 
+#else
       conn = net_http_connection_new("http://api.mumblecore.org/hello", "POST", body);
 #endif
       break;
@@ -1282,27 +1282,6 @@ void audio_callback(void)
 
 #endif
 
-void mrboom_deal_with_autofire()
-{
-   if (autofire() == false)
-   {
-      if (isGameActive())
-      {
-         for (int i = 0; i < numberOfPlayers(); i++)
-         {
-            if (isAIActiveForPlayer(i) == false)
-            {
-               if (bombInCell(xPlayer(i), yPlayer(i)))
-               {
-                  log_debug("autofire p:%d i:%d ", i, getInputForPlayer(i));
-                  mrboom_update_input(button_b, getInputForPlayer(i), 0, false);
-               }
-            }
-         }
-      }
-   }
-}
-
 #ifdef DEBUG
 BotState botStates[nb_dyna];
 #endif
